==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1.2-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1.2
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-7of3aSmSBD34JdmIIK1HRR

key:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-7of3aSmSBD34JdmIIK1HRR

license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  2027f3448872bfaaff95fb2f6ccc6cb5
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
    Prettyprinter.Convert.AnsiWlPprint

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-convert-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1.2-7of3aSmSBD34JdmIIK1HRR

depends:
    ansi-terminal-1.0.2-EhzJoAzi53XHL1K3CBirLP
    ansi-wl-pprint-0.6.9-Ek0s1I1ayXkDp3rSkFMQlv base-4.17.2.1
    prettyprinter-1.7.1-CoJGvDI2pdVEruBWSEYoT9
    prettyprinter-ansi-terminal-1.1.3-97LWSlOEzK6Dnl4KT2bUEq text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1.2-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1.2
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-CJpm4WNCqk39d82GNxd7gz

key:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-CJpm4WNCqk39d82GNxd7gz

license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  da3a7651f475be72ba9e17c033199f09
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
    Prettyprinter.Convert.AnsiWlPprint

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-convert-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1.2-CJpm4WNCqk39d82GNxd7gz

depends:
    ansi-terminal-1.0.2-EhzJoAzi53XHL1K3CBirLP
    ansi-wl-pprint-0.6.9-Ek0s1I1ayXkDp3rSkFMQlv base-4.17.2.1
    prettyprinter-1.7.1-6KCRwZiz9dxAfJnrHaz498
    prettyprinter-ansi-terminal-1.1.3-DsjS54B6SVRJcQWBCbeS0Q text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
